@@ -5,7 +5,7 @@ import (
 
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
-	"github.com/superfly/flyctl/api"
+	fly "github.com/superfly/fly-go"
 )
 
 func TestSettersWithService(t *testing.T) {
@@ -19,43 +19,21 @@ func TestSettersWithService(t *testing.T) {
 	assert.Equal(t, cfg.Services, []Service{{
 		InternalPort: 1234,
 		Protocol:     "tcp",
-		Concurrency: &api.MachineServiceConcurrency{
+		Concurrency: &fly.MachineServiceConcurrency{
 			Type:      "connections",
 			HardLimit: 34,
 			SoftLimit: 12,
 		},
 		HTTPChecks: []*ServiceHTTPCheck{{
-			Interval:          api.MustParseDuration("10s"),
-			Timeout:           api.MustParseDuration("2s"),
-			GracePeriod:       api.MustParseDuration("5s"),
-			HTTPMethod:        api.Pointer("GET"),
-			HTTPPath:          api.Pointer("/status"),
-			HTTPProtocol:      api.Pointer("http"),
-			HTTPTLSSkipVerify: api.Pointer(false),
+			Interval:          fly.MustParseDuration("10s"),
+			Timeout:           fly.MustParseDuration("2s"),
+			GracePeriod:       fly.MustParseDuration("5s"),
+			HTTPMethod:        fly.Pointer("GET"),
+			HTTPPath:          fly.Pointer("/status"),
+			HTTPProtocol:      fly.Pointer("http"),
+			HTTPTLSSkipVerify: fly.Pointer(false),
 		}},
 	}})
-	assert.Equal(t, map[string]any{
-		"app": "setters",
-		"services": []any{map[string]any{
-			"internal_port": 1234,
-			"protocol":      "tcp",
-			"concurrency": map[string]any{
-				"type":       "connections",
-				"hard_limit": 34,
-				"soft_limit": 12,
-			},
-			"http_checks": []map[string]any{{
-				"interval":        10000,
-				"grace_period":    "5s",
-				"method":          "get",
-				"path":            "/status",
-				"protocol":        "http",
-				"restart_limit":   0,
-				"timeout":         2000,
-				"tls_skip_verify": false,
-			}},
-		}},
-	}, cfg.RawDefinition)
 }
 
 func TestSettersWithHTTPService(t *testing.T) {
@@ -69,7 +47,7 @@ func TestSettersWithHTTPService(t *testing.T) {
 	assert.Empty(t, cfg.Services)
 	assert.Equal(t, cfg.HTTPService, &HTTPService{
 		InternalPort: 1234,
-		Concurrency: &api.MachineServiceConcurrency{
+		Concurrency: &fly.MachineServiceConcurrency{
 			Type:      "connections",
 			HardLimit: 34,
 			SoftLimit: 12,
@@ -77,18 +55,17 @@ func TestSettersWithHTTPService(t *testing.T) {
 	})
 	assert.Equal(t, cfg.Checks, map[string]*ToplevelCheck{
 		"status": {
-			Port:              api.Pointer(1234),
-			Type:              api.Pointer("http"),
-			Interval:          api.MustParseDuration("10s"),
-			Timeout:           api.MustParseDuration("2s"),
-			GracePeriod:       api.MustParseDuration("5s"),
-			HTTPMethod:        api.Pointer("GET"),
-			HTTPPath:          api.Pointer("/status"),
-			HTTPProtocol:      api.Pointer("http"),
-			HTTPTLSSkipVerify: api.Pointer(false),
+			Port:              fly.Pointer(1234),
+			Type:              fly.Pointer("http"),
+			Interval:          fly.MustParseDuration("10s"),
+			Timeout:           fly.MustParseDuration("2s"),
+			GracePeriod:       fly.MustParseDuration("5s"),
+			HTTPMethod:        fly.Pointer("GET"),
+			HTTPPath:          fly.Pointer("/status"),
+			HTTPProtocol:      fly.Pointer("http"),
+			HTTPTLSSkipVerify: fly.Pointer(false),
 		},
 	})
-	// No need to test RawDefinition because http_service is machines only
 }
 
 func TestSettersWithouServices(t *testing.T) {
@@ -98,7 +75,6 @@ func TestSettersWithouServices(t *testing.T) {
 	cfg.SetConcurrency(12, 34)
 	assert.Nil(t, cfg.Services, nil)
 	assert.Nil(t, cfg.HTTPService, nil)
-	assert.Equal(t, cfg.RawDefinition, map[string]any{})
 }
 
 func TestSetEnvVariable(t *testing.T) {
@@ -110,13 +86,6 @@ func TestSetEnvVariable(t *testing.T) {
 		"b": "2",
 		"c": "3",
 	})
-	assert.Equal(t, cfg.RawDefinition, map[string]any{
-		"env": map[string]string{
-			"a": "1",
-			"b": "2",
-			"c": "3",
-		},
-	})
 }
 
 func TestReleaseCommand(t *testing.T) {
@@ -125,11 +94,6 @@ func TestReleaseCommand(t *testing.T) {
 	assert.Equal(t, cfg.Deploy, &Deploy{
 		ReleaseCommand: "/bin/app/run migrate",
 	})
-	assert.Equal(t, cfg.RawDefinition, map[string]any{
-		"deploy": map[string]string{
-			"release_command": "/bin/app/run migrate",
-		},
-	})
 }
 
 func TestReleaseCommand_DeploySectionExists(t *testing.T) {
@@ -141,13 +105,6 @@ func TestReleaseCommand_DeploySectionExists(t *testing.T) {
 		ReleaseCommand: "/bin/app/run migrate",
 		Strategy:       "immediate",
 	})
-	assert.Equal(t, cfg.RawDefinition, map[string]any{
-		"app": "setters",
-		"deploy": map[string]any{
-			"release_command": "/bin/app/run migrate",
-			"strategy":        "immediate",
-		},
-	})
 }
 
 func TestSetDocker(t *testing.T) {
@@ -158,12 +115,6 @@ func TestSetDocker(t *testing.T) {
 		Entrypoint: []string{"/entry"},
 		Cmd:        []string{"/cmd"},
 	})
-	assert.Equal(t, cfg.RawDefinition, map[string]any{
-		"experimental": map[string]string{
-			"entrypoint": "/entry",
-			"cmd":        "/cmd",
-		},
-	})
 }
 
 func TestSetDocker_ExperimentalSectionExists(t *testing.T) {
@@ -177,14 +128,6 @@ func TestSetDocker_ExperimentalSectionExists(t *testing.T) {
 		Cmd:        []string{"/cmd"},
 		Exec:       []string{"/exec"},
 	})
-	assert.Equal(t, cfg.RawDefinition, map[string]any{
-		"app": "setters",
-		"experimental": map[string]any{
-			"entrypoint": "/entry",
-			"cmd":        "/cmd",
-			"exec":       "/exec",
-		},
-	})
 }
 
 func TestSetProcesses(t *testing.T) {
@@ -195,12 +138,6 @@ func TestSetProcesses(t *testing.T) {
 		Entrypoint: []string{"/entry"},
 		Cmd:        []string{"/cmd"},
 	})
-	assert.Equal(t, cfg.RawDefinition, map[string]any{
-		"experimental": map[string]string{
-			"entrypoint": "/entry",
-			"cmd":        "/cmd",
-		},
-	})
 }
 
 func TestSetProcesses_SectionExists(t *testing.T) {
@@ -214,14 +151,6 @@ func TestSetProcesses_SectionExists(t *testing.T) {
 		"back": "run-back",
 		"foo":  "bar",
 	})
-	assert.Equal(t, cfg.RawDefinition, map[string]any{
-		"app": "setters",
-		"processes": map[string]any{
-			"app":  "run-web",
-			"back": "run-back",
-			"foo":  "bar",
-		},
-	})
 }
 
 func TestSetStatics(t *testing.T) {
@@ -230,27 +159,16 @@ func TestSetStatics(t *testing.T) {
 	assert.Equal(t, cfg.Statics, []Static{
 		{GuestPath: "/guest", UrlPrefix: "/prefix"},
 	})
-	assert.Equal(t, cfg.RawDefinition, map[string]any{
-		"statics": []Static{
-			{GuestPath: "/guest", UrlPrefix: "/prefix"},
-		},
-	})
 }
 
 func TestSetVolumes(t *testing.T) {
 	cfg := NewConfig()
 	cfg.SetMounts([]Mount{{Source: "data", Destination: "/data"}})
 	assert.Equal(t, cfg.Mounts, []Mount{{Source: "data", Destination: "/data"}})
-	assert.Equal(t, cfg.RawDefinition, map[string]any{
-		"mounts": []Mount{
-			{Source: "data", Destination: "/data"},
-		},
-	})
 }
 
 func TestSetKillSignal(t *testing.T) {
 	cfg := NewConfig()
 	cfg.SetKillSignal("TERM")
-	assert.Equal(t, cfg.KillSignal, api.Pointer("TERM"))
-	assert.Equal(t, cfg.RawDefinition, map[string]any{"kill_signal": "TERM"})
+	assert.Equal(t, cfg.KillSignal, fly.Pointer("TERM"))
 }
